@@ -17,6 +17,8 @@ import pprint
 import yaml
 
 # Set default log level to "INFO"
+from requests_ms_auth.ms_session_config import MsSessionConfig
+
 logging.basicConfig(level=logging.INFO)
 
 # Create the logger we will use
@@ -31,7 +33,7 @@ if __name__ == "__main__":
     logger.info(f"Loading credentials from {filename}")
     auth_config = {}
     with open(filename, "r") as stream:
-        auth_config = yaml.safe_load(stream)
+        auth_config = MsSessionConfig(**yaml.safe_load(stream))
     logger.info("Loaded credentials:\n" + pprint.pformat(auth_config))
 
     # 2. Instanciate a session with authentication dict as parameters
